#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CLZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CLZ_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/clz.hpp>

#endif
